#
# fishing.R, 18 Sep 22
#
# Data from:
# SiP dataset

library("plyr")


sip=read.csv("SiP_learning/Sip-task-info.csv", as.is=TRUE)
sip_date=read.csv("SiP_learning/est-act-dates.csv", as.is=TRUE)
sip_date$EstimateOn=as.Date(sip_date$EstimateOn, format="%d-%b-%y")
sip_date$StartedOn=as.Date(sip_date$StartedOn, format="%d-%b-%y")
sip_date$CompletedOn=as.Date(sip_date$CompletedOn, format="%d-%b-%y")

sip=merge(sip, sip_date)
sip$wait_time=as.numeric(sip$StartedOn-sip$EstimateOn)
sip$wait_time[sip$wait_time <= 0]=NA

# One row from each task
sip_u=subset(sip, !duplicated(TaskNumber))

# Any connection between task estimate and waiting time?

plot(sip_u$HoursEstimate, sip_u$wait_time, log="xy")
l_s=loess.smooth(log(sip_u$HoursEstimate+0.1), log(sip_u$wait_time+0.1), span=0.4)
lines(exp(l_s$x), exp(l_s$y))


wt_mod=glm(wait_time ~ HoursEstimate, data=sip_u)
wt_mod=glm(log(wait_time) ~ log(HoursEstimate), data=sip_u)
summary(wt_mod)


# Number of items in the wait queue over time

# Don't count tasks estimated/started on same day
sip_w=subset(sip_u, EstimateOn < StartedOn)

start_date=min(sip_w$EstimateOn, na.rm=TRUE)
last_date=max(sip_w$StartedOn, na.rm=TRUE)

inprogress=rep(0, 1+as.numeric(last_date-start_date))

dum=d_ply(sip_w, .(TaskNumber), function(df)
					{
					day_range=1+as.numeric(df$EstimateOn-start_date):as.numeric(df$StartedOn-start_date)
					inprogress[day_range]<<-inprogress[day_range]+1
					})

# Plot used in blog post
plot(inprogress, col=pal_col[2],
	xaxs="i", yaxs="i",
	xlim=c(0, length(inprogress)),
	xlab="Days since SiP start", ylab="Tasks waiting")
lines(rollmean(inprogress, k=7), col=pal_col[1])

plot(count(inprogress), log="y")


